
// Nodelist of all of DIVs that will need bg image and bg color.
const gridItems = document.querySelectorAll('.grid-item');

// Buttons to show hidden forms and to close any opened panels
const modeToggle = document.querySelector('.mode-panel-toggle');
const closePanes = document.querySelector('.close-panes');

// Container for the two forms
const modePanel = document.querySelector('mode-panel-container');

// Form to select the blend mode
const theModeForm = document.querySelector('form');

// Form input to select the background color
const colorPicker = document.querySelector(".color-input");

const body = document.body;

// An array of images to load randomly.
const potentialImages = [
  'http://picsum.photos/1000/1000/?random',
  'http://picsum.photos/1000/1000/?random',
  'http://picsum.photos/g/1000/1000/?random',
  'http://picsum.photos/1000/1000/?blur',
  'http://picsum.photos/1000/1000/?random?blur',
  'http://picsum.photos/1000/1000/?gravity=center',
  'http://picsum.photos/2000/1000/?gravity=center',
  'http://picsum.photos/800/1000/?gravity=center',
  'http://picsum.photos/1400/1200/?gravity=center',
  'http://picsum.photos/1600/1200/?gravity=center',
  'http://picsum.photos/1000/700/?gravity=south',
  'http://picsum.photos/1000/400/?gravity=west',
  'http://picsum.photos/1200/1000/?gravity=east',
  'http://picsum.photos/g/1000/1000/?random',
  'http://picsum.photos/g/1600/1000/?random',
  'http://picsum.photos/g/2400/1200/?random',
  'http://picsum.photos/g/1600/1900/?random'
];




initialSetup();


// When modeToggle button is clicked add or remove
// 'open-menu' class from BODY. This will trigger a
// CSS transition that is styled using descendent selectors.
modeToggle.addEventListener('click', function(){
  body.classList.toggle('open-menu');
});

// When the "close panes" button is clicked, find
// all panes with a class of "open" and then
// remove that class. The removal of the class will
// also trigger a CSS transition.
closePanes.addEventListener('click', function(){
  const openPanes = document.querySelectorAll('.open');

  openPanes.forEach(function(pane){
    pane.classList.remove('open');
  });

});


// When the value of the color picker changes, set the
// value of a CSS variable (defined in the body in CSS)
// to the returned value.

// CSS Variables are actually officially known as
// CSS CUSTOM PROPERTIES: this is why we use the
// setProperty method to change the value of a
// CSS Variable.

// The eventListener here is added to the form. On click,
// we query for the checked input.

theModeForm.addEventListener('change', function(){
  const blendMode = this.querySelector('input:checked').value;
  body.style.setProperty('--blendMode', blendMode);
})

// When the colorPicker value changes, set the bg color
// of all the panels to that value.
colorPicker.addEventListener('change', function(){
  setBgColor(this.value);
})



// Generate random bg color and bg image for each of the
// panes. Add eventListener to each so the css-hidden textual
// content can be transitioned in on click.
function initialSetup () {

  for (let i=0; i<gridItems.length; i++) {

      gridItems[i].style.backgroundColor = randBgColor();
      gridItems[i].style.backgroundImage = randBgImg();

      gridItems[i].addEventListener('click', function(){
          const thisBg = this.style.backgroundColor;
          this.querySelector('.item-description').style.backgroundColor = thisBg;
          this.classList.toggle('open');
      });
  }
}


// Random color in HSL format. The saturation and
// lightness values could be multiplied by 100% rather
// than the numbers used here but we don't want them
// getting too light or too dark.
function randBgColor(){

  const hue = Math.round(Math.random() * 360);
  const sat = Math.round(Math.random() * 80) + 10;
  const light = Math.round(Math.random() * 70) + 20;

  const hsl = `hsl(${hue},${sat}%,${light}%)`;

  return (hsl);
}

// Select random image from the array and return it
// wrapped in url() to serve as background-image value.
function randBgImg() {
    const randImg = Math.floor(Math.random() * potentialImages.length);
    const randImgURL = `url('${potentialImages[randImg]}')`;
    return randImgURL;
}


function setBgColor(value){
  gridItems.forEach(function(griditem){
    griditem.style.backgroundColor = value;
  });
}
